@@ -1,10 +1,10 @@
-/* $Id: lockvalidator.h 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: lockvalidator.h 135976 2020-02-04 10:35:17Z bird $ */
 /** @file
  * IPRT - Internal RTLockValidator header.
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2020 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -24,8 +24,11 @@
  * terms and conditions of either the GPL or the CDDL or both.
  */
 
-#ifndef ___iprt_internal_lockvalidator_h
-#define ___iprt_internal_lockvalidator_h
+#ifndef IPRT_INCLUDED_INTERNAL_lockvalidator_h
+#define IPRT_INCLUDED_INTERNAL_lockvalidator_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 #include <iprt/types.h>
 #include <iprt/lockvalidator.h>
@@ -112,5 +115,5 @@ DECLHIDDEN(void)    rtLockValidatorSerializeDestructLeave(void);
 
 RT_C_DECLS_END
 
-#endif
+#endif /* !IPRT_INCLUDED_INTERNAL_lockvalidator_h */
 
