@@ -1,4 +1,4 @@
-/* $Id: SUPDrv-linux.c 145017 2021-06-09 12:14:27Z vgalitsy $ */
+/* $Id: SUPDrv-linux.c 147612 2021-10-18 12:27:53Z bird $ */
 /** @file
  * VBoxDrv - The VirtualBox Support Driver - Linux specifics.
  */
@@ -1420,15 +1420,12 @@ SUPR0DECL(int) SUPR0HCPhysToVirt(RTHCPHYS HCPhys, void **ppv)
 }
 
 
-RTDECL(int) SUPR0Printf(const char *pszFormat, ...)
+RTDECL(int) SUPR0PrintfV(const char *pszFormat, va_list va)
 {
-    va_list va;
     char    szMsg[512];
     IPRT_LINUX_SAVE_EFL_AC();
 
-    va_start(va, pszFormat);
     RTStrPrintfV(szMsg, sizeof(szMsg) - 1, pszFormat, va);
-    va_end(va);
     szMsg[sizeof(szMsg) - 1] = '\0';
 
     printk("%s", szMsg);
