@@ -1,4 +1,4 @@
-/* $Id: VBoxNetFlt-linux.c 142842 2021-02-17 19:47:29Z paulson $ */
+/* $Id: VBoxNetFlt-linux.c 150609 2022-03-21 21:07:44Z vgalitsy $ */
 /** @file
  * VBoxNetFlt - Network Filter Driver (Host), Linux Specific Code.
  */
@@ -733,7 +733,7 @@ static struct sk_buff *vboxNetFltLinuxSkBufFromSG(PVBOXNETFLTINS pThis, PINTNETS
     {
         default:
             AssertMsgFailed(("%u (%s)\n", pSG->GsoCtx.u8Type, PDMNetGsoTypeName((PDMNETWORKGSOTYPE)pSG->GsoCtx.u8Type) ));
-            /* fall thru */
+            RT_FALL_THRU();
         case PDMNETWORKGSOTYPE_INVALID:
             fGsoType = 0;
             break;
